==> nextcloud-20.0.8p0.tgz: nextcloud/apps/survey_client/l10n/bg.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Последно изпращане на данни: {on}",
    "An error occurred while sending your report." : "Възникна грешка при изпращането на данните.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Приложения <em>(за всяко: име, версия, включено/изключено)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Базата данни <em>(тип, версия, размер)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Информация за криптирането <em>(ползва ли се?, кой е стандартния модул)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Брой споделяния <em>(по тип и permission setting)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP средата <em>(версия, лимит на паметта, max. execution time, макс. размер за файл)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Данни за сървъра <em>(версия, memcache, състояние на locking/previews/avatars)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Статистика <em>(брой на: файлове, потребители, storages per type, коментари и етикети)</em>",
    "Usage survey" : "Проучване",
    "Help improve Nextcloud" : "Помогнете за развитието на Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Желаете ли да помогнете в усъвършенстването на Nextcloud, чрез изпращане на анонимни данни за текущата инсталация? Може да спрете изпращането по всяко време от Административни > Проучване.",
    "Not now" : "Не сега",
    "Send usage" : "Изпрати данни",
    "Never" : "Никога",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Изпраща анонимни данни, с цел усъвършенстване на Nextcloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Изпращайки анонимни данни за текущата инсталация за усъвършенстването\n        на Nextcloud. Ако пожелаете, можете да спирате и пускате изпращането\n        на данни по всяко време.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Можете да помогнете в усъвършенстването на Nextcloud като изпращате данни за текущата инсталация.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Отнасяме се много сериозно към поверителността на данните ви. Стандартно функционалността е изключена, а ако решите да я включите данните ще бъдат изпращани анонимно, като ви се предоставя възможността да избирате какъв тип данни да изпращате. Когато получим нови данни изтриваме предходните. Upload a clean report to delete all data currently stored on the server",
    "Send new report now" : "Изпрати данни сега",
    "Send usage survey monthly" : "Изпращай данни за ползването ежемесечно",
    "Data to send" : "Данни за изпращане",
    "Last report sent on: %s" : "Последно изпращане на данни: %s",
    "Last report" : "Последно изпращане"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-23.0.12p1.tgz: nextcloud/apps/survey_client/l10n/bg.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Последно изпращане на данни: {on}",
    "An error occurred while sending your report." : "Възникна грешка при изпращането на данните.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Приложения <em>(за всяко: име, версия, включено/изключено)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Базата данни <em>(тип, версия, размер)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Информация за криптирането <em>(ползва ли се?, кой е стандартния модул)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Брой споделяния <em>(по тип и permission setting)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP средата <em>(версия, лимит на паметта, max. execution time, макс. размер за файл)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Данни за сървъра <em>(версия, memcache, състояние на locking/previews/avatars)</em>",
    "Statistic <em>(number of files, users, storages per type, comments and tags)</em>" : "Статистика <em>(брой на: файлове, потребители, storages per type, коментари и етикети)</em>",
    "Usage survey" : "Проучване",
    "Help improve Nextcloud" : "Помогнете за развитието на Nextcloud",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Желаете ли да помогнете в усъвършенстването на Nextcloud, чрез изпращане на анонимни данни за текущата инсталация? Може да спрете изпращането по всяко време от Административни > Проучване.",
    "Not now" : "Не сега",
    "Send usage" : "Изпрати данни",
    "Never" : "Никога",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Изпраща анонимни данни, с цел усъвършенстване на Nextcloud.",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "Изпраща анонимни данни до Nextcloud, за да ни помогне да подобрим Nextcloud. Вие\n\t\t имате винаги пълен контрол върху съдържанието, изпратено до Nextcloud и можете да го деактивирате\n\t\tотново по всяко време.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Можете да помогнете в усъвършенстването на Nextcloud като изпращате данни за текущата инсталация.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Отнасяме се много сериозно към поверителността на данните ви. Стандартно функционалността е изключена, а ако решите да я включите данните ще бъдат изпращани анонимно, като ви се предоставя възможността да избирате какъв тип данни да изпращате. Когато получим нови данни изтриваме предходните. Upload a clean report to delete all data currently stored on the server",
    "Send new report now" : "Изпрати данни сега",
    "Send usage survey monthly" : "Изпращай данни за ползването ежемесечно",
    "Data to send" : "Данни за изпращане",
    "Last report sent on: %s" : "Последно изпращане на данни: %s",
    "Last report" : "Последно изпращане",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "Изпращайки анонимни данни за текущата инсталация за усъвършенстването\n        на Nextcloud. Ако пожелаете, можете да спирате и пускате изпращането\n        на данни по всяко време."
},
"nplurals=2; plural=(n != 1);");
